from extras.plugins import PluginMenuItem

menu_items = (
    PluginMenuItem(
        link='plugins:ucbox_plugin:number_list_view',
        link_text='Numbers',
        buttons=()
    ),
    PluginMenuItem(
        link='plugins:ucbox_plugin:trunk_list_view',
        link_text='Trunks',
        buttons=()
    ),
    PluginMenuItem(
        link='plugins:ucbox_plugin:UCCluster_list_view',
        link_text='UCClusters',
        buttons=()
    ),
    PluginMenuItem(
        link='plugins:ucbox_plugin:devicepool_list_view',
        link_text='Device Pools',
        buttons=()
    ),
)
